==> ksy-metaplex-js-one-4.12.11.tgz: package/src/actions/transactions.ts <==
import { Keypair, PublicKey, SendOptions } from '@solana/web3.js';
import { Wallet } from '../wallet';
import { Connection } from '../Connection';
import { Transaction } from '@metaplex-foundation/mpl-core';

/** Parameters for {@link sendTransaction} **/
export interface SendTransactionParams {
  connection: Connection;
  wallet: Wallet;
  txs: Transaction[];
  signers?: Keypair[];
  options?: SendOptions;
  feePayer?: PublicKey;  //MrChaos
}

/**
 * Sign and send transactions for validation
 * @return This action returns the resulting transaction id once it has been executed
 */
export const sendTransaction = async ({
  connection,
  wallet,
  txs,
  signers = [],
  options,
  feePayer // MrChaos
}: SendTransactionParams): Promise<string> => {
  let tx = Transaction.fromCombined(txs, { feePayer: wallet.adapter?.feePayer ?? wallet.publicKey});  // MrChaos
  tx.recentBlockhash = (await connection.getRecentBlockhash()).blockhash;
  console.log("********====================test==============================");

  console.log("*********[ksy] wallet3333=", wallet.wallets.wallet.adapter.feePayer);
  console.log("*********[ksy] wallet.adapter=", wallet.adapter);
  console.log("*********[ksy] wallet.adapter.feePayer=", wallet.adapter?.feePayer);
  if (signers.length) {
    //tx.partialSign(...signers); //0927 일단 주석처리 후 테스트 MrChaos
  }
  tx = await wallet.signTransaction(tx);
  console.log("********* web3j-deprecated:sendTransaction - before sendRawTransaction");
  console.log("********* web3j-deprecated:sendTransaction - before sendRawTransaction : signers");
  console.log("*********[ksy] wallet=", wallet);
  console.log("*********[ksy] wallet.adapter=", wallet.adapter);
  console.log("*********[ksy] wallet.adapter.feePayer=", wallet.adapter?.feePayer);
  signers.forEach(signer => {
    console.log("Signer : ",signer.publicKey.toBase58());
  });
  tx.signatures.forEach(signature => {
    console.log("Signer Of TX : ",signature.publicKey.toBase58());
  });
  console.log("********* web3j-deprecated:sendTransaction - before sendRawTransaction - Instructions");  
  console.log("*********[ksy] wallet=", wallet);
  console.log("*********[ksy] wallet.adapter=", wallet.adapter);
  console.log("*********[ksy] wallet.adapter.feePayer=", wallet.adapter?.feePayer);
  tx.instructions.forEach(ins => {
    console.log("******************* Ins Program:",ins.programId.toBase58());
    ins.keys.forEach(k => {
      console.log("Key : ",k.pubkey.toBase58(),", isSigner : ",k.isSigner, ", isWrite : ", k.isWritable);
    });
  });

  console.log("********* web3j-deprecated:sendTransaction - before sendRawTransaction : verify signature=",tx.verifySignatures());
  
  return connection.sendRawTransaction(tx.serialize(), options);
};

==> ksy-metaplex-js-one-4.12.13.tgz: package/src/actions/transactions.ts <==
import { Keypair, PublicKey, SendOptions } from '@solana/web3.js';
import { Wallet } from '../wallet';
import { Connection } from '../Connection';
import { Transaction } from '@metaplex-foundation/mpl-core'; //ksy
import {WalletContextState} from '@solana/wallet-adapter-react' //ksy

/** Parameters for {@link sendTransaction} **/
export interface SendTransactionParams {
  connection: Connection;
  wallet: Wallet;
  wallets: WalletContextState; //ksy
  txs: Transaction[];
  signers?: Keypair[];
  options?: SendOptions;
  feePayer?: PublicKey;  //MrChaos
}

/**
 * Sign and send transactions for validation
 * @return This action returns the resulting transaction id once it has been executed
 */
export const sendTransaction = async ({
  connection,
  wallet,
  wallets, //ksy
  txs,
  signers = [],
  options,
  feePayer // MrChaos
}: SendTransactionParams): Promise<string> => {
  let tx = Transaction.fromCombined(txs, { feePayer: wallet.adapter?.feePayer ?? wallet.publicKey});  // MrChaos
  tx.recentBlockhash = (await connection.getRecentBlockhash()).blockhash;
  console.log("********====================test==============================");
  console.log("*********[ksy] wallet3333=", wallet.wallet.adapter.feePayer);
  console.log("*********[ksy] wallet3333=", wallets.wallet.adapter.feePayer);
  console.log("*********[ksy] wallet3333=", wallets.feePayer);
  //console.log("*********[ksy] wallet3333=", wallets.adapter.feePayer);
  console.log("*********[ksy] wallet.adapter=", wallet.adapter);
  console.log("*********[ksy] wallet.adapter.feePayer=", wallet.adapter?.feePayer);
  if (signers.length) {
    //tx.partialSign(...signers); //0927 일단 주석처리 후 테스트 MrChaos
  }
  tx = await wallet.signTransaction(tx);
  console.log("********* web3j-deprecated:sendTransaction - before sendRawTransaction");
  console.log("********* web3j-deprecated:sendTransaction - before sendRawTransaction : signers");
  console.log("*********[ksy] wallet=", wallet);
  console.log("*********[ksy] wallet.adapter=", wallet.adapter);
  console.log("*********[ksy] wallet.adapter.feePayer=", wallet.adapter?.feePayer);
  signers.forEach(signer => {
    console.log("Signer : ",signer.publicKey.toBase58());
  });
  tx.signatures.forEach(signature => {
    console.log("Signer Of TX : ",signature.publicKey.toBase58());
  });
  console.log("********* web3j-deprecated:sendTransaction - before sendRawTransaction - Instructions");  
  console.log("*********[ksy] wallet=", wallet);
  console.log("*********[ksy] wallet.adapter=", wallet.adapter);
  console.log("*********[ksy] wallet.adapter.feePayer=", wallet.adapter?.feePayer);
  tx.instructions.forEach(ins => {
    console.log("******************* Ins Program:",ins.programId.toBase58());
    ins.keys.forEach(k => {
      console.log("Key : ",k.pubkey.toBase58(),", isSigner : ",k.isSigner, ", isWrite : ", k.isWritable);
    });
  });

  console.log("********* web3j-deprecated:sendTransaction - before sendRawTransaction : verify signature=",tx.verifySignatures());
  
  return connection.sendRawTransaction(tx.serialize(), options);
};
